==> reporter_1.0.5.tar.gz: reporter/tests/testthat/test-write_report_text.R <==
context("Write Report Text Tests")

base_path <- "c:/packages/reporter/tests/testthat"

base_path <- tempdir()

test_that("page_template_text() works as expected.", {
  
  
  rpt <- create_report("fork.out") %>% 
    titles("Here is a test title.") %>% 
    footnotes("Test footnote")
  
  rpt$line_size <- 140
  
  
  ptt <- page_template_text(rpt)
  
  expect_equal(length(ptt$titles), 2)
  expect_equal(length(ptt$footnotes), 2)
  expect_equal(length(ptt$page_header), 0)
  expect_equal(length(ptt$page_footer), 0)
  
  
  rpt1 <- create_report("fork.out") 
  
  rpt1$line_size <- 140
  
  
  ptt1 <- page_template_text(rpt1)
  
  expect_equal(length(ptt1$titles), 0)
  expect_equal(length(ptt1$footnotes), 0)
  expect_equal(length(ptt1$page_header), 0)
  expect_equal(length(ptt1$page_footer), 0)
  
  
  
  rpt2 <- create_report("fork.out") %>% 
    page_header(left = c("Something1", "Something2"), right = "Nothing") %>% 
    titles("Here is a test title.", "There is a title") %>% 
    footnotes("Test footnote", "Test footnote 2") %>% 
    page_footer(center = "confidential")
  
  rpt2$line_size <- 140
  
  ptt2 <- page_template_text(rpt2)
  
  expect_equal(length(ptt2$titles), 3)
  expect_equal(length(ptt2$footnotes), 3)
  expect_equal(length(ptt2$page_header), 2)
  expect_equal(length(ptt2$page_footer), 2)
  
  # No line size.  Should get error.
  rpt3 <- create_report("fork.out") 
  expect_error(page_template_text(rpt3))
  
  rpt4 <- create_report("fork.out") %>% 
    titles(paste0(rep("W", 200), collapse =""))
  rpt4$line_size <- 140
  expect_error(page_template_text(rpt4))
  
})


# test_that("write_page_numbers() works as expected.", {
#   
#   fp <- file.path(base_path, "text/text4.out")
#   
#   rtp <- create_report(fp) %>% 
#     page_footer(right = "Page [pg] of [tpg]")
#   
#   res2 <- write_page_numbers(rtp)
#   
#   res2
#   
#   expect_equal(grepl("[pg]", 
#   
#   
# })

==> reporter_1.1.2.tar.gz: reporter/tests/testthat/test-write_report_text.R <==
context("Write Report Text Tests")

base_path <- "c:/packages/reporter/tests/testthat"

base_path <- tempdir()

test_that("page_template_text() works as expected.", {
  
  
  rpt <- create_report("fork.out") %>% 
    titles("Here is a test title.") %>% 
    footnotes("Test footnote")
  
  rpt$line_size <- 140
  
  
  ptt <- page_template_text(rpt)
  
  expect_equal(length(ptt$titles), 2)
  expect_equal(length(ptt$footnotes), 2)
  expect_equal(length(ptt$page_header), 0)
  expect_equal(length(ptt$page_footer), 0)
  
  
  rpt1 <- create_report("fork.out") 
  
  rpt1$line_size <- 140
  
  
  ptt1 <- page_template_text(rpt1)
  
  expect_equal(length(ptt1$titles), 0)
  expect_equal(length(ptt1$footnotes), 0)
  expect_equal(length(ptt1$page_header), 0)
  expect_equal(length(ptt1$page_footer), 0)
  
  
  
  rpt2 <- create_report("fork.out") %>% 
    page_header(left = c("Something1", "Something2"), right = "Nothing") %>% 
    titles("Here is a test title.", "There is a title") %>% 
    footnotes("Test footnote", "Test footnote 2") %>% 
    page_footer(center = "confidential")
  
  rpt2$line_size <- 140
  
  ptt2 <- page_template_text(rpt2)
  
  expect_equal(length(ptt2$titles), 3)
  expect_equal(length(ptt2$footnotes), 3)
  expect_equal(length(ptt2$page_header), 2)
  expect_equal(length(ptt2$page_footer), 2)
  
  # No line size.  Should get error.
  rpt3 <- create_report("fork.out") 
  expect_error(page_template_text(rpt3))
  
  rpt4 <- create_report("fork.out") %>% 
    titles(paste0(rep("W", 200), collapse =""))
  rpt4$line_size <- 140
  expect_warning(page_template_text(rpt4))
  
})


# test_that("write_page_numbers() works as expected.", {
#   
#   fp <- file.path(base_path, "text/text4.out")
#   
#   rtp <- create_report(fp) %>% 
#     page_footer(right = "Page [pg] of [tpg]")
#   
#   res2 <- write_page_numbers(rtp)
#   
#   res2
#   
#   expect_equal(grepl("[pg]", 
#   
#   
# })
